<?php
namespace Bushelpowered\Api\Payments\V1\Request;
        
class CreatePaymentDetailsRequest 
{
    /** @var \Bushelpowered\Api\Payments\V1\Enums\PaymentOrigin $origin */
    public \Bushelpowered\Api\Payments\V1\Enums\PaymentOrigin $origin;
    /** @var \Bushelpowered\Api\Payments\V1\Enums\PaymentType $paymentType */
    public \Bushelpowered\Api\Payments\V1\Enums\PaymentType $paymentType;
    /** @var string $fundingSourceId The id of the funding source to be used. If the origin of this payment is bushel then this should be an id of a wallet funding source. If the origin is card, then this should be the id of the card record.*/
    public string $fundingSourceId;
    /** @var string $startingAmount The starting dollar amount of the payment before surcharges*/
    public string $startingAmount;
    /** @var null|string $comments Allows a user to say something that they want to about this payment. Required for oneTime payments.*/
    public ?string $comments = null;
    /** @var \Bushelpowered\Api\Payments\V1\Enums\PaymentCurrency $currency */
    public \Bushelpowered\Api\Payments\V1\Enums\PaymentCurrency $currency;
    /** @var null|string $processOn The date when the payment should be processed. Leave this null if the payment should be processed immediately. of yyyy-MM-dd format, IE: 2023-10-04*/
    public ?string $processOn = null;
    /** @var \Bushelpowered\Api\Payments\V1\Model\PaymentAssociation[]|null $associations This will be required if paymentType is invoice or settlement*/
    public ?array $associations = null;

    /**
     * @param  \Bushelpowered\Api\Payments\V1\Enums\PaymentOrigin  $origin 
     * @param  \Bushelpowered\Api\Payments\V1\Enums\PaymentType  $paymentType 
     * @param  string  $fundingSourceId The id of the funding source to be used. If the origin of this payment is bushel then this should be an id of a wallet funding source. If the origin is card, then this should be the id of the card record.
     * @param  string  $startingAmount The starting dollar amount of the payment before surcharges
     * @param  null|string  $comments Allows a user to say something that they want to about this payment. Required for oneTime payments.
     * @param  \Bushelpowered\Api\Payments\V1\Enums\PaymentCurrency  $currency 
     * @param  null|string  $processOn The date when the payment should be processed. Leave this null if the payment should be processed immediately. of yyyy-MM-dd format, IE: 2023-10-04
     * @param  \Bushelpowered\Api\Payments\V1\Model\PaymentAssociation[]|null  $associations This will be required if paymentType is invoice or settlement
     */
    public function __construct(\Bushelpowered\Api\Payments\V1\Enums\PaymentOrigin $origin, \Bushelpowered\Api\Payments\V1\Enums\PaymentType $paymentType, string $fundingSourceId, string $startingAmount, ?string $comments, \Bushelpowered\Api\Payments\V1\Enums\PaymentCurrency $currency, ?string $processOn, ?array $associations)
    {
        $this->origin = $origin;
        $this->paymentType = $paymentType;
        $this->fundingSourceId = $fundingSourceId;
        $this->startingAmount = $startingAmount;
        $this->comments = $comments;
        $this->currency = $currency;
        $this->processOn = $processOn;
        $this->associations = $associations;
    }
    

}